==> vue-dialog-box-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dialog-box/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconClose, IconFullscreen, IconMinscreen } from '@opentinyvue/vue-icon';
import ActionSheet from '@opentinyvue/vue-action-sheet';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconClose: IconClose(),
    IconFullscreen: IconFullscreen(),
    IconMinscreen: IconMinscreen(),
    TinyActionSheet: ActionSheet
  },
  emits: ["update:visible", "change", "before-close", "open", "close", "opened", "confirm", "cancel", "closed", "drag-start", "drag-move", "drag-end"],
  props: [].concat(props, ["resize", "isFormReset", "visible", "title", "modal", "modalAppendToBody", "appendToBody", "lockScroll", "closeOnClickModal", "closeOnPressEscape", "showClose", "width", "fullscreen", "top", "center", "draggable", "showHeader", "rightSlide", "destroyOnClose", "dialogClass", "beforeClose", "maxHeight", "customStyle", "noAnimation"]),
  model: {
    prop: "visible",
    event: "update:visible"
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [_vm.state.current !== "default" ? _c("div", [_c("transition", {
    attrs: {
      "duration": _vm.noAnimation ? 0 : void 0,
      "name": _vm.state.animationName
    },
    on: {
      "after-enter": _vm.afterEnter,
      "after-leave": _vm.afterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    class: ["fixed inset-0 m-0 flex items-center", _vm.dialogClass],
    attrs: {
      "data-tag": "tiny-dialog-box__wrapper"
    },
    on: {
      "click": function click($event) {
        if ($event.target !== $event.currentTarget) return null;
        return _vm.handleWrapperClick.apply(null, arguments);
      }
    }
  }, [(_vm.destroyOnClose ? _vm.visible : true) ? _c("div", {
    key: _vm.state.key,
    ref: "dialog",
    staticClass: "absolute bg-color-bg-1 border-none overflow-hidden shadow-xl rounded flex flex-col",
    class: [{
      "left-0 top-0 w-screen h-screen": _vm.state.isFull,
      "text-center": _vm.center,
      "flex flex-col rounded-none": _vm.rightSlide
    }],
    style: _vm.state.style,
    attrs: {
      "data-tag": "tiny-dialog-box"
    }
  }, [_vm.showHeader ? _c("div", {
    staticClass: "px-6 py-4 leading-5.5 bg-color-bg-1 flex justify-between items-center border-b border-b-color-bg-3",
    attrs: {
      "data-tag": "tiny-dialog-box__header"
    },
    on: {
      "mousedown": _vm.handleDrag
    }
  }, [_vm._t("title", function() {
    return [_c("span", {
      staticClass: "text-sm text-color-text-primary mr-4 flex-1 font-bold",
      attrs: {
        "data-tag": "tiny-dialog-box__title"
      }
    }, [_vm._v(_vm._s(_vm.title))])];
  }), _vm.resize && !_vm.state.isFull ? _c("button", {
    staticClass: "border-none p-0 leading-none cursor-pointer focus:outline-0",
    attrs: {
      "type": "button",
      "data-tag": "tiny-dialog-box__headerbtn",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        return _vm.toggleFullScreen(true);
      }
    }
  }, [_c("icon-fullscreen", {
    staticClass: "fill-color-text-primary text-base hover:fill-color-brand",
    attrs: {
      "data-tag": "tiny-svg-size tiny-dialog-box__close"
    }
  })], 1) : _vm._e(), _vm.resize && _vm.state.isFull ? _c("button", {
    staticClass: "border-none p-0 leading-none cursor-pointer focus:outline-0",
    attrs: {
      "type": "button",
      "data-tag": "tiny-dialog-box__headerbtn",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        return _vm.toggleFullScreen(false);
      }
    }
  }, [_c("icon-minscreen", {
    staticClass: "fill-color-text-primary text-base hover:fill-color-brand",
    attrs: {
      "data-tag": "tiny-svg-size tiny-dialog-box__close"
    }
  })], 1) : _vm._e(), _vm.showClose ? _c("button", {
    staticClass: "border-none p-0 leading-none cursor-pointer focus:outline-0",
    attrs: {
      "type": "button",
      "data-tag": "tiny-dialog-box__headerbtn",
      "aria-label": "Close"
    },
    on: {
      "click": function click($event) {
        return _vm.handleClose("close", $event);
      }
    }
  }, [_c("icon-close", {
    staticClass: "fill-color-text-primary text-base hover:fill-color-brand",
    attrs: {
      "data-tag": "tiny-svg-size tiny-dialog-box__close"
    }
  })], 1) : _vm._e()], 2) : _vm._e(), _c("div", {
    staticClass: "text-left pt-0 pr-6 pb-0 pl-6 mb-3 mt-3 text-color-text-primary leading-5.5 text-sm overflow-auto",
    class: [_vm.rightSlide || _vm.state.isFull ? "max-h-[none] flex-auto" : "max-h-[65vh]"],
    attrs: {
      "data-tag": "tiny-dialog-box__body"
    }
  }, [_vm._t("default")], 2), _vm.slots.footer ? _c("div", {
    staticClass: "pt-4 pr-6 pb-4 pl-6 text-right box-border border-t border-t-color-bg-3 [&_[data-tag=tiny-button]]:mx-1 [&_[data-tag=tiny-button]]:my-0 [&_[data-tag=tiny-toolbar]_[data-tag=tiny-button]]:my-0 [&_[data-tag=tiny-toolbar]_[data-tag=tiny-button]]:mx-1",
    attrs: {
      "data-tag": "tiny-dialog-box__footer"
    }
  }, [_vm._t("footer", null, {
    "beforeClose": _vm.beforeClose
  })], 2) : _vm._e()]) : _vm._e()])])], 1) : _vm._e(), _vm.state.current === "default" ? _c("div", [(_vm.destroyOnClose ? _vm.visible : true) ? _c("tiny-action-sheet", _vm._b({
    ref: "dialog",
    attrs: {
      "show-footer": true,
      "mask": _vm.modal,
      "mask-closable": _vm.closeOnClickModal,
      "before-close": _vm.beforeClose
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:visible", $event);
      }
    },
    scopedSlots: _vm._u([_vm._l(_vm.slots, function(value, name) {
      return {
        key: name,
        fn: function fn(scopeData) {
          return [_c("div", {
            key: name,
            class: {
              "flex w-full justify-between px-4 [&_[data-tag=tiny-button]]:flex-grow [&_[data-tag=tiny-button]:nth-child(2)]:ml-2": name === "footer",
              "px-4 min-h-[250px]": name === "default"
            }
          }, [_vm._t(name, null, null, scopeData)], 2)];
        }
      };
    })], null, true)
  }, "tiny-action-sheet", _vm.$props, false)) : _vm._e()], 1) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-dialog-box-2.23.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/dialog-box/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconClose, IconFullscreen, IconMinscreen } from '@opentinyvue/vue-icon';
import ActionSheet from '@opentinyvue/vue-action-sheet';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    IconClose: IconClose(),
    IconFullscreen: IconFullscreen(),
    IconMinscreen: IconMinscreen(),
    TinyActionSheet: ActionSheet
  },
  emits: ["update:visible", "change", "before-close", "open", "close", "opened", "confirm", "cancel", "closed", "drag-start", "drag-move", "drag-end"],
  props: [].concat(props, ["resize", "isFormReset", "visible", "title", "modal", "modalAppendToBody", "appendToBody", "lockScroll", "closeOnClickModal", "closeOnPressEscape", "showClose", "width", "fullscreen", "top", "center", "draggable", "showHeader", "rightSlide", "destroyOnClose", "dialogClass", "beforeClose", "maxHeight", "customStyle", "noAnimation"]),
  model: {
    prop: "visible",
    event: "update:visible"
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [_vm.state.current !== "default" ? _c("div", [_c("transition", {
    attrs: {
      "duration": _vm.noAnimation ? 0 : void 0,
      "name": _vm.state.animationName
    },
    on: {
      "after-enter": _vm.afterEnter,
      "after-leave": _vm.afterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    class: ["fixed inset-0 m-0 flex items-center", _vm.dialogClass],
    attrs: {
      "data-tag": "tiny-dialog-box__wrapper"
    },
    on: {
      "click": function click($event) {
        if ($event.target !== $event.currentTarget) return null;
        return _vm.handleWrapperClick.apply(null, arguments);
      }
    }
  }, [(_vm.destroyOnClose ? _vm.visible : true) ? _c("div", {
    key: _vm.state.key,
    ref: "dialog",
    staticClass: "absolute bg-color-bg-1 border-none overflow-hidden shadow-xl rounded flex flex-col",
    class: [{
      "left-0 top-0 w-screen h-screen": _vm.state.isFull,
      "text-center": _vm.center,
      "flex flex-col rounded-none": _vm.rightSlide
    }],
    style: _vm.state.style,
    attrs: {
      "data-tag": "tiny-dialog-box"
    }
  }, [_vm.showHeader ? _c("div", {
    staticClass: "px-6 py-4 leading-5.5 bg-color-bg-1 flex justify-between items-center border-b border-color-fill-1",
    attrs: {
      "data-tag": "tiny-dialog-box__header"
    },
    on: {
      "mousedown": _vm.handleDrag
    }
  }, [_vm._t("title", function() {
    return [_c("span", {
      staticClass: "text-sm text-color-text-primary mr-4 flex-1 font-bold",
      attrs: {
        "data-tag": "tiny-dialog-box__title"
      }
    }, [_vm._v(_vm._s(_vm.title))])];
  }), _vm.resize && !_vm.state.isFull ? _c("button", {
    staticClass: "border-none p-0 leading-none cursor-pointer focus:outline-0",
    attrs: {
      "type": "button",
      "data-tag": "tiny-dialog-box__headerbtn",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        return _vm.toggleFullScreen(true);
      }
    }
  }, [_c("icon-fullscreen", {
    staticClass: "fill-color-text-primary text-base hover:fill-color-brand",
    attrs: {
      "data-tag": "tiny-svg-size tiny-dialog-box__close"
    }
  })], 1) : _vm._e(), _vm.resize && _vm.state.isFull ? _c("button", {
    staticClass: "border-none p-0 leading-none cursor-pointer focus:outline-0",
    attrs: {
      "type": "button",
      "data-tag": "tiny-dialog-box__headerbtn",
      "aria-label": "Resize"
    },
    on: {
      "click": function click($event) {
        return _vm.toggleFullScreen(false);
      }
    }
  }, [_c("icon-minscreen", {
    staticClass: "fill-color-text-primary text-base hover:fill-color-brand",
    attrs: {
      "data-tag": "tiny-svg-size tiny-dialog-box__close"
    }
  })], 1) : _vm._e(), _vm.showClose ? _c("button", {
    staticClass: "border-none p-0 leading-none cursor-pointer focus:outline-0",
    attrs: {
      "type": "button",
      "data-tag": "tiny-dialog-box__headerbtn",
      "aria-label": "Close"
    },
    on: {
      "click": function click($event) {
        return _vm.handleClose("close", $event);
      }
    }
  }, [_c("icon-close", {
    staticClass: "fill-color-text-primary text-base hover:fill-color-brand",
    attrs: {
      "data-tag": "tiny-svg-size tiny-dialog-box__close"
    }
  })], 1) : _vm._e()], 2) : _vm._e(), _c("div", {
    staticClass: "text-left pt-0 pr-6 pb-0 pl-6 mb-3 mt-3 text-color-text-primary leading-5.5 text-sm overflow-auto",
    class: [_vm.rightSlide || _vm.state.isFull ? "max-h-[none] flex-auto" : "max-h-[65vh]"],
    attrs: {
      "data-tag": "tiny-dialog-box__body"
    }
  }, [_vm._t("default")], 2), _vm.slots.footer ? _c("div", {
    staticClass: "pt-4 pr-6 pb-4 pl-6 text-right box-border border-t border-color-fill-1 [&_[data-tag=tiny-button]]:mx-1 [&_[data-tag=tiny-button]]:my-0 [&_[data-tag=tiny-toolbar]_[data-tag=tiny-button]]:my-0 [&_[data-tag=tiny-toolbar]_[data-tag=tiny-button]]:mx-1",
    attrs: {
      "data-tag": "tiny-dialog-box__footer"
    }
  }, [_vm._t("footer", null, {
    "beforeClose": _vm.beforeClose
  })], 2) : _vm._e()]) : _vm._e()])])], 1) : _vm._e(), _vm.state.current === "default" ? _c("div", [(_vm.destroyOnClose ? _vm.visible : true) ? _c("tiny-action-sheet", _vm._b({
    ref: "dialog",
    attrs: {
      "show-footer": true,
      "mask": _vm.modal,
      "mask-closable": _vm.closeOnClickModal,
      "before-close": _vm.beforeClose
    },
    on: {
      "update:visible": function updateVisible($event) {
        return _vm.$emit("update:visible", $event);
      }
    },
    scopedSlots: _vm._u([_vm._l(_vm.slots, function(value, name) {
      return {
        key: name,
        fn: function fn(scopeData) {
          return [_c("div", {
            key: name,
            class: {
              "flex w-full justify-between px-4 [&_[data-tag=tiny-button]]:flex-grow [&_[data-tag=tiny-button]:nth-child(2)]:ml-2": name === "footer",
              "px-4 min-h-[250px]": name === "default"
            }
          }, [_vm._t(name, null, null, scopeData)], 2)];
        }
      };
    })], null, true)
  }, "tiny-action-sheet", _vm.$props, false)) : _vm._e()], 1) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
